@@ -19,7 +19,7 @@ REMOVE_FROM_CURRENT_CONDITION: tuple = (
     "Link",
 )
 REMOVE_FROM_FORECAST: tuple = ("Sun", "Moon", "Sources", "MobileLink", "Link")
-TEMPERATURES = ("Temperature", "RealFeelTemperature", "RealFeelTemperatureShade")
+TEMPERATURES: tuple = ("Temperature", "RealFeelTemperature", "RealFeelTemperatureShade")
 URLS: dict = {
     ATTR_GEOPOSITION: "locations/v1/cities/geoposition/search?apikey={api_key}&q={lat}%2C{lon}",
     ATTR_CURRENT_CONDITIONS: "currentconditions/v1/{location_key}?apikey={api_key}&details=true",
